ChangeOfStateDetector

Struct ChangeOfStateDetector 

pub struct ChangeOfStateDetector {
    pub alarm_values: Vec<u32>,
    pub notification_class: u32,
    pub notify_type: u32,
    pub event_enable: u8,
    pub time_delay: u32,
    pub event_state: EventState,
    pub acked_transitions: u8,
}
CHANGE_OF_STATE event detector for binary and multi-state objects.

Transitions to OFFNORMAL when the monitored value matches any value in the alarm_values list. Returns to NORMAL when the value no longer matches any alarm value.

Fields

alarm_values: Vec<u32>

Values that trigger an OFFNORMAL state.

notification_class: u32notify_type: u32event_enable: u8time_delay: u32event_state: EventStateacked_transitions: u8

Implementations

Source

impl ChangeOfStateDetector

pub fn evaluate(&mut self, present_value: u32) -> Option<EventStateChange>

Evaluate the present value against alarm_values.

Returns Some(EventStateChange) if the event state changed and the corresponding event_enable bit is set.