EventStateChange

Struct EventStateChange 

pub struct EventStateChange {
    pub from: EventState,
    pub to: EventState,
}
A detected change in event state.

Fields

from: EventState

The previous event state.

to: EventState

The new event state.

Implementations

Source

impl EventStateChange

pub fn event_type(&self) -> EventType

Derive the BACnet EventType from the state transition.

If either the from or to state is HIGH_LIMIT or LOW_LIMIT, the event type is OUT_OF_RANGE. Otherwise it is CHANGE_OF_STATE.

pub fn transition(&self) -> EventTransition

Derive the event transition category from the state change.

Per Clause 13.2.5:

  • to == NORMALToNormal
  • to == FAULTToFault
  • Everything else (OFFNORMAL, HIGH_LIMIT, LOW_LIMIT) → ToOffnormal