pub struct EventStateChange {
pub from: EventState,
pub to: EventState,
}Expand description
A detected change in event state.
Fields
from: EventStateThe previous event state.
to: EventStateThe new event state.
Implementations
Sourceimpl EventStateChange
impl EventStateChange
Sourcepub fn event_type(&self) -> EventType
pub fn event_type(&self) -> EventType
Derive the BACnet EventType from the state transition.
If either the from or to state is HIGH_LIMIT or LOW_LIMIT,
the event type is OUT_OF_RANGE. Otherwise it is CHANGE_OF_STATE.
Sourcepub fn transition(&self) -> EventTransition
pub fn transition(&self) -> EventTransition
Derive the event transition category from the state change.
Per Clause 13.2.5:
to == NORMAL→ToNormalto == FAULT→ToFault- Everything else (OFFNORMAL, HIGH_LIMIT, LOW_LIMIT) →
ToOffnormal