pub struct EventEnrollmentObject { /* private fields */ }Expand description
BACnet EventEnrollment object.
Provides algorithmic event detection for a referenced object property. The event_parameters are stored as raw bytes; full structured decoding is deferred to a future enhancement.
Implementations
Sourceimpl EventEnrollmentObject
impl EventEnrollmentObject
Sourcepub fn new(
instance: u32,
name: impl Into<String>,
event_type: u32,
) -> Result<Self, Error>
pub fn new( instance: u32, name: impl Into<String>, event_type: u32, ) -> Result<Self, Error>
Create a new EventEnrollment object.
event_type is the BACnet EventType enumeration value.
Sourcepub fn set_description(&mut self, desc: impl Into<String>)
pub fn set_description(&mut self, desc: impl Into<String>)
Set the description string.
Sourcepub fn set_object_property_reference(
&mut self,
reference: Option<BACnetDeviceObjectPropertyReference>,
)
pub fn set_object_property_reference( &mut self, reference: Option<BACnetDeviceObjectPropertyReference>, )
Set the object property reference.
Sourcepub fn set_event_parameters(&mut self, params: Vec<u8>)
pub fn set_event_parameters(&mut self, params: Vec<u8>)
Set the event parameters (raw bytes).
Sourcepub fn set_fault_parameters(&mut self, fp: Option<FaultParameters>)
pub fn set_fault_parameters(&mut self, fp: Option<FaultParameters>)
Set the fault parameters for this event enrollment.
Sourcepub fn set_event_state(&mut self, state: u32)
pub fn set_event_state(&mut self, state: u32)
Set the event state (raw u32).
Sourcepub fn set_notification_class(&mut self, nc: u32)
pub fn set_notification_class(&mut self, nc: u32)
Set the notification class.
Sourcepub fn set_event_enable(&mut self, enable: u8)
pub fn set_event_enable(&mut self, enable: u8)
Set the event enable bitmask (3 bits: TO_OFFNORMAL, TO_FAULT, TO_NORMAL).